@@ -1,19 +1,10 @@
-# coding=utf-8
-import gettext
+from gettext import gettext as _
+from typing import Optional
 from uuid import UUID
 
-from blueman.Constants import GETTEXT_PACKAGE, LOCALEDIR
-
-translation = gettext.translation(GETTEXT_PACKAGE, LOCALEDIR, fallback=True)
-try:
-    translation.install(unicode=True)
-except TypeError:
-    translation.install()
-
 # https://www.bluetooth.com/specifications/assigned-numbers/service-discovery
 # http://git.kernel.org/cgit/bluetooth/bluez.git/tree/lib/sdp.h
 
-BLUEMAN_GENERIC_CONNECT_ID = 0x0000
 SDP_SERVER_SVCLASS_ID = 0x1000
 BROWSE_GRP_DESC_SVCLASS_ID = 0x1001
 PUBLIC_BROWSE_GROUP = 0x1002
@@ -90,175 +81,174 @@ HDP_SOURCE_SVCLASS_ID = 0x1401
 HDP_SINK_SVCLASS_ID = 0x1402
 GENERIC_ACCESS_SVCLASS_ID = 0x1800
 GENERIC_ATTRIB_SVCLASS_ID = 0x1801
+BATTERY_SERVICE_SVCLASS_ID = 0x180F
 APPLE_AGENT_SVCLASS_ID = 0x2112
 
 uuid_names = {
-    # 0x0000 is for our generic connect
-    0x0000: "Generic Connect",
-    0x0001: "SDP",
-    0x0002: "UDP",
-    0x0003: "RFCOMM",
-    0x0004: "TCP",
-    0x0005: "TCS-BIN",
-    0x0006: "TCS-AT",
-    0x0007: "ATT",
-    0x0008: "OBEX",
-    0x0009: "IP",
-    0x000a: "FTP",
-    0x000c: "HTTP",
-    0x000e: "WSP",
-    0x000f: "BNEP",
-    0x0010: "UPnP/ESDP",
-    0x0011: "HIDP",
-    0x0012: "Hardcopy Control Channel",
-    0x0014: "Hardcopy Data Channel",
-    0x0016: "Hardcopy Notification",
-    0x0017: "AVCTP",
-    0x0019: "AVDTP",
-    0x001b: "CMTP",
-    0x001d: "UDI_C-Plane",
-    0x001e: "Multi-Channel Adaptation Protocol (MCAP)",
-    0x001f: "Multi-Channel Adaptation Protocol (MCAP)",
-    0x0100: "L2CAP",
-    0x1000: "ServiceDiscoveryServerServiceClassID",
-    0x1001: "BrowseGroupDescriptorServiceClassID",
-    0x1002: "Public Browse Group",
-    0x1101: "Serial Port",
-    0x1102: "LAN Access Using PPP",
+    0x0001: _("SDP"),
+    0x0002: _("UDP"),
+    0x0003: _("RFCOMM"),
+    0x0004: _("TCP"),
+    0x0005: _("TCS-BIN"),
+    0x0006: _("TCS-AT"),
+    0x0007: _("ATT"),
+    0x0008: _("OBEX"),
+    0x0009: _("IP"),
+    0x000a: _("FTP"),
+    0x000c: _("HTTP"),
+    0x000e: _("WSP"),
+    0x000f: _("BNEP"),
+    0x0010: _("UPnP/ESDP"),
+    0x0011: _("HIDP"),
+    0x0012: _("Hardcopy Control Channel"),
+    0x0014: _("Hardcopy Data Channel"),
+    0x0016: _("Hardcopy Notification"),
+    0x0017: _("AVCTP"),
+    0x0019: _("AVDTP"),
+    0x001b: _("CMTP"),
+    0x001d: _("UDI_C-Plane"),
+    0x001e: _("Multi-Channel Adaptation Protocol (MCAP)"),
+    0x001f: _("Multi-Channel Adaptation Protocol (MCAP)"),
+    0x0100: _("L2CAP"),
+    0x1000: _("ServiceDiscoveryServerServiceClassID"),
+    0x1001: _("BrowseGroupDescriptorServiceClassID"),
+    0x1002: _("Public Browse Group"),
+    0x1101: _("Serial Port"),
+    0x1102: _("LAN Access Using PPP"),
     0x1103: _("Dialup Networking (DUN)"),
-    0x1104: "IrMC Sync",
-    0x1105: "OBEX Object Push",
-    0x1106: "OBEX File Transfer",
-    0x1107: "IrMC Sync Command",
-    0x1108: "Headset",
-    0x1109: "Cordless Telephony",
+    0x1104: _("IrMC Sync"),
+    0x1105: _("OBEX Object Push"),
+    0x1106: _("OBEX File Transfer"),
+    0x1107: _("IrMC Sync Command"),
+    0x1108: _("Headset"),
+    0x1109: _("Cordless Telephony"),
     0x110a: _("Audio Source"),
     0x110b: _("Audio Sink"),
-    0x110c: "Remote Control Target",
-    0x110d: "Advanced Audio",
-    0x110e: "Remote Control",
-    0x110f: "Video Conferencing",
-    0x1110: "Intercom",
-    0x1111: "Fax",
-    0x1112: "Headset Audio Gateway",
-    0x1113: "WAP",
-    0x1114: "WAP Client",
-    0x1115: "PANU",
+    0x110c: _("Remote Control Target"),
+    0x110d: _("Advanced Audio"),
+    0x110e: _("Remote Control"),
+    0x110f: _("Video Conferencing"),
+    0x1110: _("Intercom"),
+    0x1111: _("Fax"),
+    0x1112: _("Headset Audio Gateway"),
+    0x1113: _("WAP"),
+    0x1114: _("WAP Client"),
+    0x1115: _("PANU"),
     0x1116: _("Network Access Point"),
     0x1117: _("Group Network"),
-    0x1118: "DirectPrinting (BPP)",
-    0x1119: "ReferencePrinting (BPP)",
-    0x111a: "Imaging (BIP)",
-    0x111b: "ImagingResponder (BIP)",
-    0x111c: "ImagingAutomaticArchive (BIP)",
-    0x111d: "ImagingReferencedObjects (BIP)",
-    0x111e: "Handsfree",
-    0x111f: "Handsfree Audio Gateway",
-    0x1120: "DirectPrintingReferenceObjectsService (BPP)",
-    0x1121: "ReflectedUI (BPP)",
-    0x1122: "Basic Printing (BPP)",
-    0x1123: "Printing Status (BPP)",
-    0x1124: "Human Interface Device Service (HID)",
-    0x1125: "HardcopyCableReplacement (HCR)",
-    0x1126: "HCR_Print (HCR)",
-    0x1127: "HCR_Scan (HCR)",
-    0x1128: "Common ISDN Access (CIP)",
-    0x1129: "VideoConferencingGW (VCP)",
-    0x112a: "UDI-MT",
-    0x112b: "UDI-TA",
-    0x112c: "Audio/Video",
-    0x112d: "SIM Access (SAP)",
-    0x112e: "Phonebook Access (PBAP) - PCE",
-    0x112f: "Phonebook Access (PBAP) - PSE",
-    0x1130: "Phonebook Access (PBAP)",
-    0x1131: "Headset",
-    0x1132: "Message Access Server",
-    0x1133: "Message Notification Server",
-    0x1134: "Message Access Profile (MAP)",
-    0x1135: "GNSS",
-    0x1136: "GNSS Server",
-    0x1137: "3D Display",
-    0x1138: "3D Glasses",
-    0x1139: "3D Synchronization (3DSP)",
-    0x113a: "Multi-Profile Specification (MPS) Profile",
-    0x113b: "Multi-Profile Specification (MPS) Service",
-    0x113c: "Calendar, Task, and Notes (CTN) Access Service",
-    0x113d: "Calendar, Task, and Notes (CTN) Notification Service",
-    0x113e: "Calendar, Task, and Notes (CTN) Profile",
-    0x1200: "PnP Information",
-    0x1201: "Generic Networking",
-    0x1202: "Generic FileTransfer",
-    0x1203: "Generic Audio",
-    0x1204: "Generic Telephony",
-    0x1303: "Video Source",
-    0x1304: "Video Sink",
-    0x1305: "Video Distribution",
-    0x1400: "HDP",
-    0x1401: "HDP Source",
-    0x1402: "HDP Sink",
-    0x1800: "Generic Access",
-    0x1801: "Generic Attribute",
-    0x1802: "Immediate Alert",
-    0x1803: "Link Loss",
-    0x1804: "Tx Power",
-    0x1805: "Current Time Service",
-    0x1806: "Reference Time Update Service",
-    0x1807: "Next DST Change Service",
-    0x1808: "Glucose",
-    0x1809: "Health Thermometer",
-    0x180A: "Device Information",
-    0x180D: "Heart Rate",
-    0x180E: "Phone Alert Status Service",
-    0x180F: "Battery Service",
-    0x1810: "Blood Pressure",
-    0x1811: "Alert Notification Service",
-    0x1812: "Human Interface Device",
-    0x1813: "Scan Parameters",
-    0x1814: "Running Speed and Cadence",
-    0x1815: "Automation IO",
-    0x1816: "Cycling Speed and Cadence",
-    0x1818: "Cycling Power",
-    0x1819: "Location and Navigation",
-    0x181A: "Environmental Sensing",
-    0x181B: "Body Composition",
-    0x181C: "User Data",
-    0x181D: "Weight Scale",
-    0x181E: "Bond Management",
-    0x181F: "Continuous Glucose Monitoring",
-    0x1820: "Internet Protocol Support",
-    0x1821: "Indoor Positioning",
-    0x1822: "Pulse Oximeter",
-    0x1823: "HTTP Proxy",
-    0x1824: "Transport Discovery",
-    0x1825: "Object Transfer",
-    0x2112: "AppleAgent",
-    0x2800: "Primary Service",
-    0x2801: "Secondary Service",
-    0x2802: "Include",
-    0x2803: "Characteristic Declaration",
-    0x2A00: "Device Name",
-    0x2A01: "Appearance",
-    0x2A02: "Peripheral Privacy Flag",
-    0x2A03: "Reconnection Address",
-    0x2A04: "Peripheral Preferred Connection Parameters",
-    0x2A05: "Service Changed",
-    0x2A23: "System ID",
-    0x2A24: "Model Number String",
-    0x2A25: "Serial Number String",
-    0x2A26: "Firmware Revision String",
-    0x2A27: "Hardware Revision String",
-    0x2A28: "Software Revision String",
-    0x2A29: "Manufacturer Name String",
-    0x2A50: "PnP ID",
-    0x2900: "Characteristic Extended Properties",
-    0x2901: "Characteristic User Description",
-    0x2902: "Client Characteristic Configuration",
-    0x2903: "Server Characteristic Configuration",
-    0x2904: "Characteristic Presentation Format",
-    0x2905: "Characteristic Aggregate Format",
-    0x2906: "Valid Range",
-    0x2907: "External Report Reference",
-    0x2908: "Report Reference",
+    0x1118: _("DirectPrinting (BPP)"),
+    0x1119: _("ReferencePrinting (BPP)"),
+    0x111a: _("Imaging (BIP)"),
+    0x111b: _("ImagingResponder (BIP)"),
+    0x111c: _("ImagingAutomaticArchive (BIP)"),
+    0x111d: _("ImagingReferencedObjects (BIP)"),
+    0x111e: _("Handsfree"),
+    0x111f: _("Handsfree Audio Gateway"),
+    0x1120: _("DirectPrintingReferenceObjectsService (BPP)"),
+    0x1121: _("ReflectedUI (BPP)"),
+    0x1122: _("Basic Printing (BPP)"),
+    0x1123: _("Printing Status (BPP)"),
+    0x1124: _("Human Interface Device Service (HID)"),
+    0x1125: _("HardcopyCableReplacement (HCR)"),
+    0x1126: _("HCR_Print (HCR)"),
+    0x1127: _("HCR_Scan (HCR)"),
+    0x1128: _("Common ISDN Access (CIP)"),
+    0x1129: _("VideoConferencingGW (VCP)"),
+    0x112a: _("UDI-MT"),
+    0x112b: _("UDI-TA"),
+    0x112c: _("Audio/Video"),
+    0x112d: _("SIM Access (SAP)"),
+    0x112e: _("Phonebook Access (PBAP) - PCE"),
+    0x112f: _("Phonebook Access (PBAP) - PSE"),
+    0x1130: _("Phonebook Access (PBAP)"),
+    0x1131: _("Headset"),
+    0x1132: _("Message Access Server"),
+    0x1133: _("Message Notification Server"),
+    0x1134: _("Message Access Profile (MAP)"),
+    0x1135: _("GNSS"),
+    0x1136: _("GNSS Server"),
+    0x1137: _("3D Display"),
+    0x1138: _("3D Glasses"),
+    0x1139: _("3D Synchronization (3DSP)"),
+    0x113a: _("Multi-Profile Specification (MPS) Profile"),
+    0x113b: _("Multi-Profile Specification (MPS) Service"),
+    0x113c: _("Calendar, Task, and Notes (CTN) Access Service"),
+    0x113d: _("Calendar, Task, and Notes (CTN) Notification Service"),
+    0x113e: _("Calendar, Task, and Notes (CTN) Profile"),
+    0x1200: _("PnP Information"),
+    0x1201: _("Generic Networking"),
+    0x1202: _("Generic FileTransfer"),
+    0x1203: _("Generic Audio"),
+    0x1204: _("Generic Telephony"),
+    0x1303: _("Video Source"),
+    0x1304: _("Video Sink"),
+    0x1305: _("Video Distribution"),
+    0x1400: _("HDP"),
+    0x1401: _("HDP Source"),
+    0x1402: _("HDP Sink"),
+    0x1800: _("Generic Access"),
+    0x1801: _("Generic Attribute"),
+    0x1802: _("Immediate Alert"),
+    0x1803: _("Link Loss"),
+    0x1804: _("Tx Power"),
+    0x1805: _("Current Time Service"),
+    0x1806: _("Reference Time Update Service"),
+    0x1807: _("Next DST Change Service"),
+    0x1808: _("Glucose"),
+    0x1809: _("Health Thermometer"),
+    0x180A: _("Device Information"),
+    0x180D: _("Heart Rate"),
+    0x180E: _("Phone Alert Status Service"),
+    0x180F: _("Battery Service"),
+    0x1810: _("Blood Pressure"),
+    0x1811: _("Alert Notification Service"),
+    0x1812: _("Human Interface Device"),
+    0x1813: _("Scan Parameters"),
+    0x1814: _("Running Speed and Cadence"),
+    0x1815: _("Automation IO"),
+    0x1816: _("Cycling Speed and Cadence"),
+    0x1818: _("Cycling Power"),
+    0x1819: _("Location and Navigation"),
+    0x181A: _("Environmental Sensing"),
+    0x181B: _("Body Composition"),
+    0x181C: _("User Data"),
+    0x181D: _("Weight Scale"),
+    0x181E: _("Bond Management"),
+    0x181F: _("Continuous Glucose Monitoring"),
+    0x1820: _("Internet Protocol Support"),
+    0x1821: _("Indoor Positioning"),
+    0x1822: _("Pulse Oximeter"),
+    0x1823: _("HTTP Proxy"),
+    0x1824: _("Transport Discovery"),
+    0x1825: _("Object Transfer"),
+    0x2112: _("AppleAgent"),
+    0x2800: _("Primary Service"),
+    0x2801: _("Secondary Service"),
+    0x2802: _("Include"),
+    0x2803: _("Characteristic Declaration"),
+    0x2A00: _("Device Name"),
+    0x2A01: _("Appearance"),
+    0x2A02: _("Peripheral Privacy Flag"),
+    0x2A03: _("Reconnection Address"),
+    0x2A04: _("Peripheral Preferred Connection Parameters"),
+    0x2A05: _("Service Changed"),
+    0x2A23: _("System ID"),
+    0x2A24: _("Model Number String"),
+    0x2A25: _("Serial Number String"),
+    0x2A26: _("Firmware Revision String"),
+    0x2A27: _("Hardware Revision String"),
+    0x2A28: _("Software Revision String"),
+    0x2A29: _("Manufacturer Name String"),
+    0x2A50: _("PnP ID"),
+    0x2900: _("Characteristic Extended Properties"),
+    0x2901: _("Characteristic User Description"),
+    0x2902: _("Client Characteristic Configuration"),
+    0x2903: _("Server Characteristic Configuration"),
+    0x2904: _("Characteristic Presentation Format"),
+    0x2905: _("Characteristic Aggregate Format"),
+    0x2906: _("Valid Range"),
+    0x2907: _("External Report Reference"),
+    0x2908: _("Report Reference"),
 }
 
 SDP_ATTR_RECORD_HANDLE = 0x0000
@@ -367,27 +357,29 @@ GATT_REPORT_REFERENCE = 0x2908
 
 
 class ServiceUUID(UUID):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+    def __init__(self, uuid: str):
+        super().__init__(uuid)
 
     @property
-    def short_uuid(self):
+    def short_uuid(self) -> Optional[int]:
         if self.reserved:
             return self.int >> 96 & 0xFFFF
+        else:
+            return None
 
     @property
-    def name(self):
-        if self.reserved:
+    def name(self) -> str:
+        if self.short_uuid:
             try:
                 return uuid_names[self.short_uuid]
             except KeyError:
                 return _("Unknown")
         elif self.int == 0:
-            return _('Auto connect profiles')
+            return _('Audio and input profiles')
         else:
             return _('Proprietary')
 
     @property
-    def reserved(self):
+    def reserved(self) -> bool:
         return self.int & UUID('FFFF0000-0000-FFFF-FFFF-FFFFFFFFFFFF').int == \
             UUID('00000000-0000-1000-8000-00805F9B34FB').int
